@@ -9,7 +9,7 @@ import time
 import utime
 # from common import led
 
-from env_sense import bme280_int as bme280
+from env_sense import BMX280 as bmx280
 from env_sense import pms7003
 from env_sense import aqi
 from env_sense import publishThingspeak
@@ -20,13 +20,12 @@ FREQUENCY_BME_MINS = 10
 FREQUENCY_AIR_MINS = 30
 # assumes BME < AIR; and that AIR is a multiple of BME
 
-# Thingspeak:
-TS_CHANNEL_ID = b'1229949'
-TS_CHANNEL_WRITE_API_KEY = b'MD2BOTGRJ8JE8J6U'
+# thingspeak credentials
+from credentials import *
 
 ts = None
 air = None
-bme = None
+bmx = None
 dummy_air = None
 
 
@@ -63,9 +62,9 @@ def ts_publish(ts, reading_bme, reading_air):
     ts.publish(data)
 
 
-# -----------------------------------------------------------------------------------------------------------
+# ------------------------------------
 # Init / read sensors
-# -----------------------------------------------------------------------------------------------------------
+# -----------------------------------
 class Sensor:
     def wakeup(self):
         pass
@@ -112,40 +111,39 @@ class SensorAir(Sensor):
 #     def read(self):
 #         return [0, 0, 0]
 
-
-class SensorBME(Sensor):
+class SensorBMX(Sensor):
     # SCL = D1 = 5 = scl_pin_id
     # SDA = D2 = 4 = sda_pin_id
 
     def __init__(self):
         i2c = machine.I2C(scl=machine.Pin(5, machine.Pin.OUT),
                           sda=machine.Pin(4))
-        self.bme = bme280.BME280(i2c=i2c)
+        self.bmx = bmx280.BMX280(i2c)
 
     def read(self):
-        t, p, h = self.bme.read_compensated_data()
-        t /= 100
-        t = t*1.8 + 32
-        p /= 256
-        h /= 1024
-        return [round(t, 1), p/100, round(h, 1)]
+        t = self.bmx.temperature * 1.8 + 32
+        p = self.bmx.pressure / 100
+        h = self.bmx.humidity
+        return [round(t, 1), p / 100, round(h, 1)]
 
     def wakeup(self):
         # first couple readings, especially after moving rooms and cold-booting tend to be outliers
         self.read()
-        time.sleep(2)
+        time.sleep(5)
         self.read()
-        time.sleep(2)
+        time.sleep(5)
 
 
 def init_sensors():
-    global ts, air, bme, dummy_air
+    global ts, air, bmx, dummy_air
     while True:
         try:
             ntptime.settime()
-            ts = publishThingspeak.ThingspeakMqtt(TS_CHANNEL_ID, TS_CHANNEL_WRITE_API_KEY)
-            air = SensorAir()
-            bme = SensorBME()
+            credentials = DEVICE_SPECIFIC_ID.get(machine.unique_id(), TS_DEFAULTS)
+            print("Initializing device for:", credentials['name'])
+            ts = publishThingspeak.ThingspeakMqtt(credentials)
+            air = Sensor()
+            bmx = SensorBMX()
             dummy_air = Sensor()
             break
         except Exception as e:
@@ -162,9 +160,9 @@ def read_sensors_and_publish(include_air=False):
     air_or_dummy = air if include_air else dummy_air
 
     air_or_dummy.wakeup()
-    bme.wakeup()
+    bmx.wakeup()
     for i in range(SAMPLES):
-        ts_publish(ts, bme.read(), air_or_dummy.read())
+        ts_publish(ts, bmx.read(), air_or_dummy.read())
         time.sleep(SECONDS_BETWEEN_READINGS)
     air_or_dummy.sleep()
 
@@ -193,10 +191,10 @@ def main():
             except OSError:
                 pass
             now = utime.localtime()
-            secs_until_next = (FREQUENCY_BME_MINS - (now[4] % FREQUENCY_BME_MINS))*60 - now[5]
+            secs_until_next = (FREQUENCY_BME_MINS - (now[4] % FREQUENCY_BME_MINS)) * 60 - now[5]
             gc.collect()
             print("Sleeping for {} seconds. Free mem: {}".format(secs_until_next, gc.mem_free()))
-            time.sleep(secs_until_next+5)  # pad so we don't start too early if the RTC runs fast
+            time.sleep(secs_until_next + 5)  # pad so we don't start too early if the RTC runs fast
             retries = 0
         except Exception as e:
             retries += 1
